:orphan:

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. include:: ../../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   started
   auto_examples/index
   references
   autoapi/index